# naivenlp

![Python package](https://github.com/luozhouyang/naivenlp/workflows/Python%20package/badge.svg)
[![PyPI version](https://badge.fury.io/py/naivenlp.svg)](https://badge.fury.io/py/naivenlp)
[![Python](https://img.shields.io/pypi/pyversions/naivenlp.svg?style=plastic)](https://badge.fury.io/py/naivenlp)


A naive toolkit for NLP.

## Tokenizers

`naivenlp` defines a interface for tokenization, you can implement your own tokeinizers easily.

By default, `naivenlp` provides `JiebaTokenizer`, which is refactoring from [jieba](https://github.com/fxsjy/jieba).


